Function amazon_sp_fba_inbound_eligibility::apis::fba_inbound_api::get_item_eligibility_preview
source · [−]pub async fn get_item_eligibility_preview(
configuration: &Configuration,
asin: &str,
program: &str,
marketplace_ids: Option<Vec<String>>
) -> Result<GetItemEligibilityPreviewResponse, Error>Expand description
This operation gets an eligibility preview for an item that you specify. You can specify the type of eligibility preview that you want (INBOUND or COMMINGLING). For INBOUND previews, you can specify the marketplace in which you want to determine the item’s eligibility. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 1 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.